@@ -141,24 +141,24 @@ class MutationRoot:
 
         return res
 
-    def change_billing_plan(self, billing_plan, billing_cycle, extra_storage, extra_throughput, custom_apps):
-        billingPlan_arg = parse_arg("billingPlan", billing_plan, is_enum=True)
-        billingCycle_arg = parse_arg(
-            "billingCycle", billing_cycle, is_enum=True)
-        extraStorage_arg = parse_arg("extraStorage", extra_storage)
-        extraThroughput_arg = parse_arg("extraThroughput", extra_throughput)
-        customApps_arg = parse_arg("customApps", custom_apps)
+    # def change_billing_plan(self, billing_plan, billing_cycle, extra_storage, extra_throughput, custom_apps):
+    #     billingPlan_arg = parse_arg("billingPlan", billing_plan, is_enum=True)
+    #     billingCycle_arg = parse_arg(
+    #         "billingCycle", billing_cycle, is_enum=True)
+    #     extraStorage_arg = parse_arg("extraStorage", extra_storage)
+    #     extraThroughput_arg = parse_arg("extraThroughput", extra_throughput)
+    #     customApps_arg = parse_arg("customApps", custom_apps)
 
-        res = self.client.mutation("mutation{changeBillingPlan(%s%s%s%s%s) }" % (
-            billingPlan_arg,
-            billingCycle_arg,
-            extraStorage_arg,
-            extraThroughput_arg,
-            customApps_arg
-        ))[
-            "changeBillingPlan"]
+    #     res = self.client.mutation("mutation{changeBillingPlan(%s%s%s%s%s) }" % (
+    #         billingPlan_arg,
+    #         billingCycle_arg,
+    #         extraStorage_arg,
+    #         extraThroughput_arg,
+    #         customApps_arg
+    #     ))[
+    #         "changeBillingPlan"]
 
-        return res
+    #     return res
 
     def change_password(self, new_password, old_password):
         new_password_arg = parse_arg("newPassword", new_password)
@@ -337,11 +337,9 @@ class MutationRoot:
 
         return wrapById(res, wrapper)
 
-    def create_thing(self, type, firmware=undefined, battery_threshold=undefined, stored_notifications=undefined):
+    def create_thing(self, type, firmware=undefined, stored_notifications=undefined):
         type_arg = parse_arg("type", type)
         firmware_arg = parse_arg("firmware", firmware)
-        battery_threshold_arg = parse_arg(
-            "batteryThreshold", battery_threshold)
         stored_notifications_arg = parse_arg(
             "storedNotifications", stored_notifications)
         res = self.client.mutation('mutation{createThing(%s%s%s%s){id}}' % (
@@ -353,14 +351,14 @@ class MutationRoot:
 
         return wrapById(res, wrapper)
 
-    def claim_thing(self, claim_code, name, environment_id, index=undefined, muted=undefined):
-        claimCode_arg = parse_arg("claimCode", claim_code)
+    def pair_thing(self, pair_code, name, environment_id, index=undefined, muted=undefined):
+        pairCode_arg = parse_arg("pairCode", pair_code)
         name_arg = parse_arg("name", name)
         environmentId_arg = parse_arg("environmentId", environment_id)
         index_arg = parse_arg("index", index)
         muted_arg = parse_arg("muted", muted)
-        res = self.client.mutation('mutation{claimThing(%s%s%s%s%s){id}}' % (
-            claimCode_arg, name_arg, index_arg, environmentId_arg, muted_arg))["claimThing"]
+        res = self.client.mutation('mutation{pairThing(%s%s%s%s%s){id}}' % (
+            pairCode_arg, name_arg, index_arg, environmentId_arg, muted_arg))["pairThing"]
 
         def wrapper(id):
             return Thing(self.client, id)
@@ -543,7 +541,7 @@ class MutationRoot:
 
         return wrapById(res, wrapper)
 
-    def thing(self, id, type=undefined, name=undefined, index=undefined, signal_status=undefined, battery_status=undefined, battery_charging=undefined, battery_threshold=undefined, firmware=undefined, muted=undefined, starred=undefined, stored_notifications=undefined):
+    def thing(self, id, type=undefined, name=undefined, index=undefined, signal_status=undefined, battery_status=undefined, battery_charging=undefined, firmware=undefined, muted=undefined, starred=undefined, stored_notifications=undefined):
         id_arg = parse_arg("id", id)
         thingType_arg = parse_arg("type", type)
         name_arg = parse_arg("name", name)
@@ -554,8 +552,6 @@ class MutationRoot:
         firmware_arg = parse_arg("firmware", firmware)
         muted_arg = parse_arg("muted", muted)
         starred_arg = parse_arg("starred", starred)
-        battery_threshold_arg = parse_arg(
-            "batteryThreshold", battery_threshold)
         stored_notifications_arg = parse_arg(
             "storedNotifications", stored_notifications)
         res = self.client.mutation('mutation{thing(%s%s%s%s%s%s%s%s%s%s%s%s){id}}' % (
@@ -767,11 +763,11 @@ class MutationRoot:
 
         return self.client.mutation('mutation{deleteThing(%s)}' % (id_arg))["deleteThing"]
 
-    def unclaimThing(self, id, reset):
+    def unpairThing(self, id, reset):
         id_arg = parse_arg("id", id)
         reset_arg = parse_arg("reset", reset)
 
-        return self.client.mutation('mutation{unclaimThing(%s%s){id}}' % (id_arg, reset_arg))["unclaimThing"]
+        return self.client.mutation('mutation{unpairThing(%s%s){id}}' % (id_arg, reset_arg))["unpairThing"]
 
     def delete_environment(self, id):
         id_arg = parse_arg("id", id)
